// frontend/pages/components/quizmodal.tsx
import React, { useEffect, useState } from 'react';
import Tesseract from 'tesseract.js';

interface QuizModalProps {
  slideImageUrl: string;
  onClose: (result: 'correct' | 'fail') => void;
  attempt: number;
}

export default function QuizModal({ slideImageUrl, onClose, attempt }: QuizModalProps) {
  const [question, setQuestion] = useState('');
  const [options, setOptions] = useState<string[]>([]);
  const [selectedOption, setSelectedOption] = useState('');
  const [correctLetter, setCorrectLetter] = useState('');
  const [feedback, setFeedback] = useState('');
  const [isCompleted, setIsCompleted] = useState(false);

  useEffect(() => {
    Tesseract.recognize(slideImageUrl, 'eng').then(({ data: { text } }) => {
      const lines = text.split('\n').filter(l => l.trim());
      const quizIndex = lines.findIndex(l => l.toLowerCase().includes('quiz'));
      if (quizIndex >= 0) {
        setQuestion(lines[quizIndex + 1]?.trim() || '');
        setOptions(lines.slice(quizIndex + 2, quizIndex + 5));
      }

      const answerLine = lines.find(l => l.toLowerCase().startsWith('correct answer'));
      if (answerLine) {
        const match = answerLine.match(/[:\-]\s*([A-Z])/i);
        if (match) {
          setCorrectLetter(match[1].toUpperCase());
        }
      }
    });
  }, [slideImageUrl]);

  const handleSubmit = () => {
    if (isCompleted) return;

    const selectedIndex = options.findIndex(opt => opt === selectedOption);
    const selectedLetter = String.fromCharCode(65 + selectedIndex); // 65 = A

    if (selectedLetter === correctLetter) {
      setIsCompleted(true);
      setFeedback('✅ Correct answer!');
      setTimeout(() => onClose('correct'), 1000);
    } else if (attempt >= 2) {
      setFeedback('❌ Max attempts reached. Restarting...');
      setTimeout(() => onClose('fail'), 1500);
    } else {
      setFeedback('❌ Wrong answer. Try again.');
      setTimeout(() => onClose('fail'), 1500);
    }
  };

  if (!question && options.length === 0) {
    return (
      <div style={styles.overlay}>
        <div style={styles.modal}>
          <p>🔍 Reading quiz from slide... Please wait.</p>
        </div>
      </div>
    );
  }

  return (
    <div style={styles.overlay}>
      <div style={styles.modal}>
        <h2>Quiz (Attempt {attempt + 1}/3)</h2>
        <p style={{ fontWeight: 'bold' }}>{question}</p>
        {options.map((option, index) => (
          <label key={index} style={styles.option}>
            <input
              type="radio"
              value={option}
              checked={selectedOption === option}
              onChange={() => !isCompleted && setSelectedOption(option)}
              disabled={isCompleted}
            />
            {option}
            {isCompleted && option === options[correctLetter.charCodeAt(0) - 65] && ' ✔️'}
          </label>
        ))}
        <button
          style={styles.submitButton}
          onClick={handleSubmit}
          disabled={!selectedOption || isCompleted}
        >
          {isCompleted ? 'Completed' : 'Submit Answer'}
        </button>
        {feedback && <p style={{ marginTop: 10 }}>{feedback}</p>}
      </div>
    </div>
  );
}

const styles: { [key: string]: React.CSSProperties } = {
  overlay: {
    position: 'fixed',
    top: 0,
    left: 0,
    width: '100vw',
    height: '100vh',
    backgroundColor: 'rgba(0,0,0,0.85)',
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    zIndex: 1000,
  },
  modal: {
    background: '#fff',
    padding: '2rem',
    borderRadius: 10,
    width: '80%',
    maxWidth: '500px',
    textAlign: 'left',
    zIndex: 1001,
  },
  option: {
    display: 'block',
    margin: '0.5rem 0',
  },
  submitButton: {
    padding: '0.5rem 1rem',
    backgroundColor: '#0070f3',
    color: '#fff',
    border: 'none',
    borderRadius: 5,
    cursor: 'pointer',
    marginTop: 10,
  },
};
