// frontend/pages/components/slideviewer.tsx
import React, { useEffect, useRef, useState } from 'react';

interface Slide {
  slideNumber: number;
  imageUrl: string;
  audioUrl: string | null;
  videoUrl: string | null;
}

interface Props {
  slide: Slide;
  currentIndex: number;
  totalSlides: number;
  isNextEnabled: boolean;
  onAudioEnd: () => void;
  onNext: () => void;
  onPrev: () => void;
  onRestart: () => void;
  resetAudio: () => void;
}

export default function SlideViewer({
  slide,
  currentIndex,
  totalSlides,
  isNextEnabled,
  onAudioEnd,
  onNext,
  onPrev,
  onRestart,
  resetAudio,
}: Props) {
  const audioRef = useRef<HTMLAudioElement>(null);
  const [showVideo, setShowVideo] = useState(false);

  useEffect(() => {
  const handleKeyDown = (e: KeyboardEvent) => {
    if (e.key === 'Escape' && showVideo) {
      setShowVideo(false);
      const videoEl = document.getElementById('video-player') as HTMLVideoElement;
      if (videoEl) {
        videoEl.pause();
      }
    }
  };

  window.addEventListener('keydown', handleKeyDown);
  return () => window.removeEventListener('keydown', handleKeyDown);
}, [showVideo]);

  useEffect(() => {
    resetAudio();
    setShowVideo(false);
    if (audioRef.current) {
      audioRef.current.load();
      audioRef.current.play().catch(() => {});
    }
  }, [slide]);

  return (
    <div style={styles.container}>
      <button style={styles.prevButton} onClick={onPrev} disabled={currentIndex === 0}>
        ◀
      </button>

      <div style={styles.content}>
        <img
          src={`http://localhost:3001${slide.imageUrl}`}
          alt="Slide"
          style={styles.image}
        />

        {slide.videoUrl && !showVideo && (
          <button
            style={styles.videoButton}
            onClick={() => setShowVideo(true)}
            title="Play Video"
          >
            ▶
          </button>
        )}

        {showVideo && slide.videoUrl && (
          <video
            controls
            autoPlay
            style={styles.videoOverlay}
            onEnded={() => setShowVideo(false)}
          >
            <source src={`http://localhost:3001${slide.videoUrl}`} type="video/mp4" />
            Your browser does not support the video tag.
          </video>
        )}

        {slide.audioUrl && (
          <audio
            ref={audioRef}
            controls
            onEnded={onAudioEnd}
            style={styles.audio}
          >
            <source src={`http://localhost:3001${slide.audioUrl}`} type="audio/mpeg" />
          </audio>
        )}
      </div>

      <button
        style={styles.nextButton}
        onClick={onNext}
        disabled={!isNextEnabled || currentIndex === totalSlides - 1}
      >
        ▶
      </button>
    </div>
  );
}

const styles: { [key: string]: React.CSSProperties } = {
  container: {
    display: 'flex',
    width: '100vw',
    height: '100vh',
    alignItems: 'center',
    justifyContent: 'space-between',
    padding: 20,
    boxSizing: 'border-box',
  },
  prevButton: {
    fontSize: '2rem',
    cursor: 'pointer',
    background: 'none',
    border: 'none',
    color: '#333',
  },
  nextButton: {
    fontSize: '2rem',
    cursor: 'pointer',
    background: 'none',
    border: 'none',
    color: '#333',
  },
  content: {
    flex: 1,
    textAlign: 'center',
    height: '100%',
    position: 'relative',
  },
  image: {
    maxHeight: 'calc(100vh - 120px)',
    width: '100%',
    maxWidth: '100%',
    objectFit: 'contain',
  },
  audio: {
    position: 'absolute',
    bottom: 20,
    left: '50%',
    transform: 'translateX(-50%)',
  },
  videoButton: {
    position: 'absolute',
    right: '25%',
    top: '50%',
    transform: 'translateY(-50%)',
    backgroundColor: '#0070f3',
    color: 'white',
    border: 'none',
    borderRadius: '50%',
    width: 50,
    height: 50,
    fontSize: '1.5rem',
    cursor: 'pointer',
    zIndex: 2,
  },
  videoOverlay: {
    position: 'absolute',
    top: '10%',
    left: '50%',
    transform: 'translateX(-50%)',
    maxWidth: '80%',
    maxHeight: '80%',
    zIndex: 10,
    backgroundColor: '#000',
    borderRadius: 8,
  },
};
