// pages/editor.tsx
import React, { useEffect, useState } from 'react';
import axios from 'axios';

interface SlideFormData {
  slideNumber: number;
  imageUrl: string;
  audioUrl: string | null;
  videoUrl: string | null;
  newImageFile?: File;
  newAudioFile?: File;
  newVideoFile?: File;
}

const BACKEND_URL = "http://localhost:3001";

const isAbsoluteUrl = (url: string) => /^(https?:|blob:)/.test(url);

const EditorPage = () => {
  const [slides, setSlides] = useState<SlideFormData[]>([]);
  const [imagePreview, setImagePreview] = useState<string | null>(null);
  const [videoPreview, setVideoPreview] = useState<string | null>(null);

  useEffect(() => {
    const fetchSlides = async () => {
      try {
        const stored = localStorage.getItem("slides");
        if (stored) {
          const parsed = JSON.parse(stored);
          if (Array.isArray(parsed)) setSlides(parsed);
          else if (parsed.slides && Array.isArray(parsed.slides)) setSlides(parsed.slides);
        }
      } catch (err) {
        console.error("Error loading slides", err);
      }
    };
    fetchSlides();
  }, []);

  const getFileName = (url: string | null): string =>
    url ? url.split('/').pop() || '' : 'No File';
  

  const getImageSrc = (slide: SlideFormData) => {
    if (slide.newImageFile) {
      return URL.createObjectURL(slide.newImageFile);
    }
    if (slide.imageUrl) {
      return isAbsoluteUrl(slide.imageUrl) ? slide.imageUrl : BACKEND_URL + slide.imageUrl;
    }
    return undefined;
  };

  const getAudioSrc = (slide: SlideFormData) => {
    if (slide.newAudioFile) {
      return URL.createObjectURL(slide.newAudioFile);
    }
    if (slide.audioUrl) {
      return isAbsoluteUrl(slide.audioUrl) ? slide.audioUrl : BACKEND_URL + slide.audioUrl;
    }
    return undefined;
  };

  const getVideoSrc = (slide: SlideFormData) => {
    if (slide.newVideoFile) {
      return URL.createObjectURL(slide.newVideoFile);
    }
    if (slide.videoUrl) {      
      return isAbsoluteUrl(slide.videoUrl) ? slide.videoUrl : BACKEND_URL + slide.videoUrl;
    }
    return undefined;
  };
  

  const handleFileChange = (index: number, type: 'audio' | 'video' | 'image', file: File) => {
    const updatedSlides = [...slides];
    if (type === 'audio') {
      updatedSlides[index].newAudioFile = file;
    } else if (type === 'video') {
      updatedSlides[index].newVideoFile = file;
    } else if (type === 'image') {
      updatedSlides[index].newImageFile = file;
    }
    setSlides(updatedSlides);
  };

  const handleInsert = (index: number, before = false) => {
    const newSlide: SlideFormData = {
      slideNumber: 0,
      imageUrl: '',
      audioUrl: null,
      videoUrl: null
    };
    const updatedSlides = [...slides];
    updatedSlides.splice(before ? index : index + 1, 0, newSlide);
    updatedSlides.forEach((s, i) => (s.slideNumber = i + 1));
    setSlides(updatedSlides);
  };

  const handleDelete = (index: number) => {
    const updatedSlides = [...slides];
    updatedSlides.splice(index, 1);
    updatedSlides.forEach((s, i) => (s.slideNumber = i + 1));
    setSlides(updatedSlides);
  };

  const handleSave = async () => {
  const formData = new FormData();
  const slideNumbers = slides.map((_, i) => (i + 1).toString());
  formData.append('slideNumbers', slideNumbers.join(','));

  await Promise.all(slides.map(async (slide, index) => {
    const slideIndex = index + 1;

    if (slide.newImageFile) {
      formData.append('slide', new File(
        [slide.newImageFile],
        `slide${slideIndex}${slide.imageUrl?.includes('_quiz') ? '_quiz' : ''}.jpg`,
        { type: slide.newImageFile.type }
      ));
    } else if (slide.imageUrl) {
      const response = await fetch(isAbsoluteUrl(slide.imageUrl) ? slide.imageUrl : BACKEND_URL + slide.imageUrl);
      const blob = await response.blob();
      formData.append('slide', new File(
        [blob],
        `slide${slideIndex}${slide.imageUrl?.includes('_quiz') ? '_quiz' : ''}.jpg`,
        { type: blob.type }
      ));
    }

    if (slide.newAudioFile) {
      formData.append('audio', new File(
        [slide.newAudioFile],
        `slide${slideIndex}.mp3`,
        { type: slide.newAudioFile.type }
      ));
    } else if (slide.audioUrl) {
      const response = await fetch(isAbsoluteUrl(slide.audioUrl) ? slide.audioUrl : BACKEND_URL + slide.audioUrl);
      const blob = await response.blob();
      formData.append('audio', new File(
        [blob],
        `slide${slideIndex}.mp3`,
        { type: blob.type }
      ));
    }

    if (slide.newVideoFile) {
      formData.append('video', new File(
        [slide.newVideoFile],
        `slide${slideIndex}.mp4`,
        { type: slide.newVideoFile.type }
      ));
    } else if (slide.videoUrl) {
      const response = await fetch(isAbsoluteUrl(slide.videoUrl) ? slide.videoUrl : BACKEND_URL + slide.videoUrl);
      const blob = await response.blob();
      formData.append('video', new File(
        [blob],
        `slide${slideIndex}.mp4`,
        { type: blob.type }
      ));
    }
  }));

  try {
    const res = await axios.post(`${BACKEND_URL}/editor/save`, formData);
    if ((res.data as any).success) {
      alert("Slides saved successfully");

      const updatedSlides = slides.map((slide, index) => {
        const slideNumber = index + 1;
        const baseName = `slide${slideNumber}`;

        return {
          slideNumber,
          imageUrl: `/slides/${baseName}${slide.imageUrl?.includes('_quiz') ? '_quiz' : ''}.jpg`,
          audioUrl: `/media/${baseName}.mp3`,
          videoUrl: slide.newVideoFile || slide.videoUrl ? `/media/${baseName}.mp4` : null,
        };
      });

      localStorage.setItem('slides', JSON.stringify({ slides: updatedSlides }));
    } else {
      alert("Failed to save slides");
    }
  } catch (err) {
    console.error("Save failed", err);
    alert("Failed to save slides");
  }
};




  return (
    <div className="p-4">
      <h1 className="text-xl font-bold mb-4">Slide Editor</h1>
      <table className="w-full border text-center">
        <thead>
          <tr>
            <th className="border p-2">Slide #</th>
            <th className="border p-2">Image</th>
            <th className="border p-2">Audio</th>
            <th className="border p-2">Video</th>
            <th className="border p-2">Upload Slide</th>
            <th className="border p-2">Upload Audio</th>
            <th className="border p-2">Upload Video</th>
            <th className="border p-2">Actions</th>
          </tr>
        </thead>
        <tbody>
          {slides.map((slide, index) => (
            <tr key={index}>
              <td className="border p-2">{slide.slideNumber}</td>
              <td className="border p-2">
                {getImageSrc(slide) ? (
                  <img
                    src={getImageSrc(slide)}
                    alt={`Slide ${slide.slideNumber}`}
                    className="w-20 h-20 object-contain cursor-pointer mx-auto"
                    onClick={() => setImagePreview(getImageSrc(slide)!)}
                  />
                ) : (
                  'No Image'
                )}
              </td>
              <td className="border p-2">
                {getAudioSrc(slide) ? (
                  <>
                    <div className="text-xs truncate">
                      {slide.newAudioFile?.name || getFileName(slide.audioUrl)}
                    </div>
                    <audio controls src={getAudioSrc(slide)} />
                  </>
                ) : (
                  'No Audio'
                )}
              </td>
              <td className="border p-2">
                {getVideoSrc(slide) ? (
                  <>
                    <div className="text-xs truncate">
                      {slide.newVideoFile?.name || getFileName(slide.videoUrl)}
                    </div>
                    <video
                      className="w-24 h-16 cursor-pointer"
                      controls
                      onClick={() => setVideoPreview(getVideoSrc(slide)!)}
                    >
                      <source src={getVideoSrc(slide)} />
                      Your browser does not support video.
                    </video>
                  </>
                ) : (
                  'No Video'
                )}
              </td>
              <td className="border p-2">
                <input
                  type="file"
                  accept="image/*"
                  onChange={(e) =>
                    e.target.files && handleFileChange(index, 'image', e.target.files[0])
                  }
                />
              </td>
              <td className="border p-2">
                <input
                  type="file"
                  accept="audio/*"
                  onChange={(e) =>
                    e.target.files && handleFileChange(index, 'audio', e.target.files[0])
                  }
                />
              </td>
              <td className="border p-2">
                <input
                  type="file"
                  accept="video/*"
                  onChange={(e) =>
                    e.target.files && handleFileChange(index, 'video', e.target.files[0])
                  }
                />
              </td>
              <td className="border p-2 text-sm space-y-1">
                <button
                  onClick={() => handleInsert(index, true)}
                  className="text-blue-600 hover:underline block"
                >
                  Insert Before
                </button>
                <button
                  onClick={() => handleInsert(index, false)}
                  className="text-blue-600 hover:underline block"
                >
                  Insert After
                </button>
                <button
                  onClick={() => handleDelete(index)}
                  className="text-red-600 hover:underline block"
                >
                  Delete
                </button>
              </td>
            </tr>
          ))}
        </tbody>
      </table>

      <button onClick={handleSave} className="btn btn-primary mt-4">
        Save Changes
      </button>

      {imagePreview && (
        <div
          className="fixed inset-0 bg-black bg-opacity-70 flex items-center justify-center z-50"
          onClick={() => setImagePreview(null)}
        >
          <img src={imagePreview} className="max-w-full max-h-full" />
        </div>
      )}

      {videoPreview && (
        <div
          className="fixed inset-0 bg-black bg-opacity-70 flex items-center justify-center z-50"
          onClick={() => setVideoPreview(null)}
        >
          <video controls autoPlay className="max-w-full max-h-full">
            <source src={videoPreview} />
          </video>
        </div>
      )}
    </div>
  );
};

export default EditorPage;
