import React, { useState } from 'react';
import axios from 'axios';
import { useRouter } from 'next/router';

interface Slide {
  slideNumber: number;
  imageUrl: string;
  audioUrl: string | null;
  videoUrl: string | null;
}

export default function Home() {
  const [pdfFile, setPdfFile] = useState<File | null>(null);
  const [zipFile, setZipFile] = useState<File | null>(null);
  const [loading, setLoading] = useState(false);
  const router = useRouter();

  const handleUpload = async () => {
    if (!pdfFile || !zipFile) {
      alert('Please select both PDF and ZIP files!');
      return;
    }

    const formData = new FormData();
    formData.append('pdf', pdfFile);
    formData.append('zip', zipFile);

    try {
      setLoading(true);
      const res = await axios.post<Slide[]>('http://localhost:3001/upload', formData, {
        headers: { 'Content-Type': 'multipart/form-data' },
        timeout: 60000,
      });
      localStorage.setItem('slides', JSON.stringify(res.data));
      router.push('/player');
    } catch (err) {
      console.error('Upload failed:', err);
      alert('Upload failed. Please try again.');
    } finally {
      setLoading(false);
    }
  };

  return (
    <div style={styles.page}>
      <div style={styles.card}>
        <h1 style={styles.heading}>📤 Upload Slides & Media</h1>

        <div style={styles.formGroup}>
          <label style={styles.label}>Upload PDF file</label>
          <input
            type="file"
            accept=".pdf"
            style={styles.input}
            onChange={(e) => setPdfFile(e.target.files?.[0] || null)}
          />
        </div>

        <div style={styles.formGroup}>
          <label style={styles.label}>Upload Media ZIP (mp3/mp4)</label>
          <input
            type="file"
            accept=".zip"
            style={styles.input}
            onChange={(e) => setZipFile(e.target.files?.[0] || null)}
          />
        </div>

        <button
          onClick={handleUpload}
          style={{
            ...styles.uploadButton,
            ...(loading ? styles.disabledButton : {}),
          }}
          disabled={loading}
        >
          {loading ? 'Uploading...' : 'Start Upload'}
        </button>
      </div>
    </div>
  );
}

const styles: { [key: string]: React.CSSProperties } = {
  page: {
    backgroundColor: '#f3f4f6',
    minHeight: '100vh',
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    padding: '1rem',
  },
  card: {
    backgroundColor: '#ffffff',
    padding: '2rem 3rem',
    borderRadius: '1rem',
    boxShadow: '0 10px 30px rgba(0, 0, 0, 0.1)',
    maxWidth: '450px',
    width: '100%',
    textAlign: 'center',
  },
  heading: {
    fontSize: '2rem',
    marginBottom: '2rem',
    color: '#111827',
    fontWeight: 600,
  },
  formGroup: {
    marginBottom: '1.5rem',
    textAlign: 'left',
  },
  label: {
    display: 'block',
    marginBottom: '0.5rem',
    color: '#374151',
    fontSize: '1rem',
    fontWeight: 500,
  },
  input: {
    width: '100%',
    padding: '0.5rem',
    border: '1px solid #d1d5db',
    borderRadius: '0.5rem',
    fontSize: '1rem',
    backgroundColor: '#f9fafb',
  },
  uploadButton: {
    width: '100%',
    padding: '0.75rem',
    fontSize: '1rem',
    backgroundColor: '#2563eb',
    color: '#ffffff',
    border: 'none',
    borderRadius: '0.5rem',
    fontWeight: 'bold',
    cursor: 'pointer',
    transition: 'all 0.3s ease',
  },
  disabledButton: {
    backgroundColor: '#93c5fd',
    cursor: 'not-allowed',
  },
};
