// frontend/pages/player.tsx
import React, { useEffect, useState } from 'react';
import QuizModal from './components/quizmodal';
import SlideViewer from './components/slideviewer';

interface Slide {
  slideNumber: number;
  imageUrl: string;
  audioUrl: string | null;
  videoUrl: string | null;
}

const backendUrl = 'http://localhost:3001';

export default function Player() {
  const [slides, setSlides] = useState<Slide[]>([]);
  const [currentIndex, setCurrentIndex] = useState(0);
  const [audioEnded, setAudioEnded] = useState(false);
  const [completedSlides, setCompletedSlides] = useState<number[]>([]);
  const [showQuiz, setShowQuiz] = useState(false);
  const [quizImageUrl, setQuizImageUrl] = useState('');
  const [quizAttempts, setQuizAttempts] = useState(0);
  const [quizRedirectMap, setQuizRedirectMap] = useState<{ [key: number]: number }>({});

  useEffect(() => {
    const stored = localStorage.getItem('slides');
    if (!stored) {
      alert('No slide data found. Please upload again.');
      return;
    }

    try {
      const parsed = JSON.parse(stored);
      const parsedSlides = parsed.slides;

      if (Array.isArray(parsedSlides) && parsedSlides.length > 0) {
        setSlides(parsedSlides);

        const quizSlides: number[] = parsedSlides
          .filter((s: Slide) => s.imageUrl.toLowerCase().includes('quiz'))
          .map((s: Slide) => s.slideNumber)
          .sort((a, b) => a - b);

        const redirectMap: { [key: number]: number } = {};
        for (let i = 0; i < quizSlides.length; i++) {
          const currentQuiz = quizSlides[i];
          const previousQuiz = quizSlides[i - 1] ?? 0; // 0 if first quiz
          const fallback = parsedSlides.find(s => s.slideNumber > previousQuiz)?.slideNumber ?? 0;
          redirectMap[currentQuiz] = fallback;
        }

        setQuizRedirectMap(redirectMap);
      } else {
        alert('Slide data is empty or invalid. Please re-upload.');
      }
    } catch (e) {
      alert('Slide data is corrupted. Please upload again.');
    }
  }, []);

  useEffect(() => {
    setAudioEnded(false);
    setShowQuiz(false);

    const currentSlide = slides[currentIndex];
    if (!currentSlide) return;

    const filename = currentSlide.imageUrl.toLowerCase();
    if (filename.includes('quiz')) {
      setQuizImageUrl(`${backendUrl}${currentSlide.imageUrl}`);
      setShowQuiz(true);
    }
  }, [currentIndex, slides]);


  const handleQuizClose = (result: 'correct' | 'fail') => {
    setShowQuiz(false);
    if (result === 'correct') {
      setCompletedSlides((prev) => [...prev, slides[currentIndex].slideNumber]);
      setCurrentIndex((prev) => prev + 1);
      setQuizAttempts(0);
    } else if (quizAttempts < 2) {
      setQuizAttempts((prev) => prev + 1);

      const failedSlideNumber = slides[currentIndex].slideNumber;
      const redirectTo = quizRedirectMap[failedSlideNumber] ?? 0;
      const newIndex = slides.findIndex(s => s.slideNumber === redirectTo);
      setCurrentIndex(newIndex >= 0 ? newIndex : 0);
    } else {
      setQuizAttempts(0); // Max attempts used, move forward
      setCurrentIndex((prev) => prev + 1);
    }
  };

  const currentSlide = slides[currentIndex];
  const isCompleted = completedSlides.includes(currentSlide?.slideNumber ?? -1);
  const isNextEnabled = audioEnded || isCompleted || !currentSlide?.audioUrl;

  const handleAudioEnd = () => {
    setAudioEnded(true);
    setCompletedSlides((prev) => [...new Set([...prev, currentSlide.slideNumber])]);
  };

  if (!currentSlide) {
    return <div style={{ padding: 20 }}><h2>No slides to display</h2></div>;
  }

  return (
    <>
    <div style={{ textAlign: 'center', margin: '10px 0', fontSize: '18px' }}>
  Slide {currentIndex + 1} of {slides.length}
</div>

      {!showQuiz && (
        <SlideViewer
          slide={currentSlide}
          currentIndex={currentIndex}
          totalSlides={slides.length}
          isNextEnabled={isNextEnabled}
          onAudioEnd={handleAudioEnd}
          onNext={() => setCurrentIndex(prev => prev + 1)}
          onPrev={() => setCurrentIndex(prev => Math.max(prev - 1, 0))}
          onRestart={() => setCurrentIndex(0)}
          resetAudio={() => setAudioEnded(false)}
        />
      )}

      {showQuiz && (
        <QuizModal
          slideImageUrl={quizImageUrl}
          onClose={handleQuizClose}
          attempt={quizAttempts}
        />
      )}
    </>
  );
}
